# Bosh Sensortec sensors

## BME680 sensor

The [BME680][] sensor from Bosh Sensortec measures relative humidity, barometric pressure, ambient temperature and gas (VOC).
The open source [driver][] provides raw measurements, such as the resistance of the gas sensing element.

The heater element of gas sensor affects the temperature and humidity measurements.
Compensated temperature and humidity measurements are available trough a closed source integration library ([BSEC][]).
The [BSEC][] provides three air quality estimates derived from raw measurements:

- index of air quality (IAQ, 0-500);
- CO2 equivalent (eCO2, ppm);
- breath VOC (bVOC), ppm).

For easy of use [BSEC][] is also provided as an [Arduino library][library],
which can be installed using the [platformio library manager] as follows:

```bash
pio lib install "BSEC Software Library"
```

[BME680]:   https://www.bosch-sensortec.com/media/boschsensortec/downloads/datasheets/bst-bme680-ds001.pdf
[driver]:   https://github.com/BoschSensortec/BME680_driver
[BSEC]:     https://www.bosch-sensortec.com/software-tools/software/bsec/
[library]:  https://github.com/BoschSensortec/BSEC-Arduino-library
[platformio]: https://platformio.org/lib/show/6979/BSEC%20Software%20Library/installation

## MCU680 module

The [GY-MCU680v1][banggood] is a chinese module with an [STM32F051K8][] mirocontroller (μC) and 3.3V low-dropout regulator (LDO).
The μC acts as UART bridge, providing [BSEC][] outputs from the BME680 sensor.

The μC and sensor operate at 3.3V, but the module can be interfaced at 5V as UART pins on the [STM32F051K8][] are 5V tolerant.
The module also breaks out the [BME680][] I2C pins, which are not 5V tolerant.

[STM32F051K8]:  https://www.st.com/en/microcontrollers-microprocessors/stm32f051k8.html
[banggood]:     https://www.banggood.com/GY-MCU680V1-BME680-Temperature-Humidity-Pressure-Indoor-Air-Quality-IAQ-Sensor-Module-p-1416437.html
[MCU680]:       http://myosuploads3.banggood.com/products/20190218/20190218203950GYMPU680.rar

## Serial communication

Under factory settings, the serial protocol is UART 9600 8N1 (3.3V/5V TTL).
The alternative 115200 BAUD rate is not supported.

### Commands

- `A5 55 3F 39`: Output all data, factory setting
- `A5 55 XX YY`: Select output data, where
  - `XX` output selection (temperature_flag `01` | rel_humidity_flag `02` | pressure_flag `04` | IAQ_flag `08` | gas_flag `10` | altitude_flag `20`)
  - `YY` message checksum `(0xA5+0x55+XX)%0x100`
- `A5 56 02 FD`: Automatic output, factory setting
- `A5 56 01 FC`: Query output
- `A5 58 01 FE`: 115200 BAUD rate
- `A5 58 02 FF`: 9600 BAUD rate, factory setting
- `A5 5A 01 00`: Save setup. Save the current settings to flash and restart according to the saved settings.
- `A5 5A 02 01`: Restore setting. Factory setting are restored, the baud rate is 9600, and all data is automatically output.

### MCU680

Under the factory settings, the module provides 7 values packed on a 20 bit message.
The following hexdump (`pms -m MCU680 -n 10 -i 10 serial -f hexdump`) shows one message per line

```hexdump
00000000: 5a 5a 3f 0f 09 7d 0a c4 01 8b 89 00 19 00 00 9e f2 00 05 19  ZZ?..}..............
00000014: 5a 5a 3f 0f 09 79 0a c5 01 8b 85 00 19 00 00 a4 83 00 05 a9  ZZ?..y..............
00000028: 5a 5a 3f 0f 09 76 0a c8 01 8b 85 00 19 00 00 ab 32 00 05 5f  ZZ?..v..........2.._
0000003c: 5a 5a 3f 0f 09 74 0a c8 01 8b 87 00 19 00 00 b0 27 00 05 59  ZZ?..t..........'..Y
00000050: 5a 5a 3f 0f 09 72 0a c9 01 8b 87 00 19 00 00 b5 33 00 05 69  ZZ?..r..........3..i
00000064: 5a 5a 3f 0f 09 70 0a d0 01 8b 83 00 19 00 00 ba 05 00 06 42  ZZ?..p.............B
00000078: 5a 5a 3f 0f 09 6f 0a d2 01 8b 83 00 19 00 00 bf 71 00 06 b4  ZZ?..o..........q...
0000008c: 5a 5a 3f 0f 09 6e 0a d0 01 8b 83 00 19 00 00 c3 6e 00 06 b2  ZZ?..n..........n...
000000a0: 5a 5a 3f 0f 09 6c 0a cf 01 8b 85 00 19 00 00 c8 ee 00 05 35  ZZ?..l.............5
000000b4: 5a 5a 3f 0f 09 6a 0a d0 01 8b 83 00 19 00 00 cc b0 00 06 f9  ZZ?..j..............
```
